@@ -17,7 +17,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with GNU CC; see the file COPYING.  If not, write to
+ * along with LVM; see the file COPYING.  If not, write to
  * the Free Software Foundation, 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA. 
  *
@@ -217,7 +217,7 @@ int main ( int argc, char **argv) {
 
    if ( opt_v > 0) printf ( "%s -- checking logical volume \"%s\" existance\n",
                             cmd, lv_name);
-   if ( lvm_tab_lv_check_exist ( lv_name) == FALSE) {
+   if ( lvm_tab_lv_check_exist ( lv_name) != TRUE) {
       fprintf ( stderr, "%s -- logical volume \"%s\" doesn't exist\n\n",
                         cmd, lv_name);
       return LVM_EE2FSADM_LV_EXIST;
