@@ -595,7 +595,7 @@ pv_move_pe_continue:
          fprintf ( stderr, "%s -- ERROR %d writing source "
                            "physical volume data on \"%s\"\n\n", 
                            cmd, ret, vg->pv[src_pv_index]->pv_name);
-         ret = -LVM_EPE_MOVE_PV_PV_STORE_WITH_PE_SRC;
+         ret = -LVM_EPE_MOVE_PV_PV_WRITE_WITH_PE_SRC;
          goto pv_move_pe_end;
       }
    }
@@ -609,7 +609,7 @@ pv_move_pe_continue:
          fprintf ( stderr, "%s -- ERROR %d writing destination "
                            "physical volume data on \"%s\"\n\n", 
                            cmd, ret, vg->pv[dst_pv_index]->pv_name);
-         ret = -LVM_EPE_MOVE_PV_PV_STORE_WITH_PE_DEST;
+         ret = -LVM_EPE_MOVE_PV_PV_WRITE_WITH_PE_DEST;
          goto pv_move_pe_end;
       }
    }
