@@ -18,7 +18,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with GNU CC; see the file COPYING.  If not, write to
+ * along with LVM; see the file COPYING.  If not, write to
  * the Free Software Foundation, 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA. 
  *
@@ -261,7 +261,7 @@ int main ( int argc, char **argv)
       if ( opt_v > 0) printf ( "%s -- checking logical volume \"%s\" "
                                "existence\n",
                                cmd, lv_name);
-      if ( ( ret = lvm_tab_lv_check_exist ( lv_name)) == FALSE) {
+      if ( ( ret = lvm_tab_lv_check_exist ( lv_name)) != TRUE) {
          fprintf ( stderr, "%s -- logical volume \"%s\" doesn't exist\n\n",
                    cmd, lv_name);
          continue;
