@@ -18,7 +18,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with GNU CC; see the file COPYING.  If not, write to
+ * along with LVM; see the file COPYING.  If not, write to
  * the Free Software Foundation, 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA. 
  *
@@ -30,6 +30,8 @@
  *    08/10/1997 - added initialization of logical volume (1st KB zero)
  *    08/11/1997 - added message if default stripe size used
  *    09/11/1997 - added lvmtab handling
+ *    18/01/1998 - added option z to give possibility to disallow zeroing 
+ *                 of newly created logical volumes
  *    29/04/1998 - changed to new lv_create_node()
  *    16/05/1998 - added lvmtab checking
  *    26/05/1998 - added message in case of low space
@@ -45,6 +47,7 @@
  *    02/09/1998 - corrected some messages
  *    20/12/1998 - added check for volume group existence
  *    26/01/1999 - made volume group directory prefix a preprocessor option
+ *    28/01/1999 - fixed logical volume path too long in command line
  *    06/02/1999 - fixed lvm_check_number() usage
  *    16/02/1999 - changed to new lv_create_node() calling convention
  *
@@ -58,14 +61,6 @@
  *
  */
 
-/*
- * Changelog
- *
- *    18/01/1998 - added option z to give possibility to disallow zeroing 
- *                 of newly created logical volumes
- *    28/01/1999 - fixed logical volume path too long in command line
- *
- */
 
 #include <lvm_user.h>
 
@@ -196,7 +191,7 @@ int main ( int argc, char **argv) {
                stripesize = LVM_DEFAULT_STRIPE_SIZE;
                opt_i++;
             } else {
-               fprintf ( stderr, "%s -- ERROR option i argument \"%s\"\n",
+               fprintf ( stderr, "%s -- ERROR option i argument \"%s\"\n\n",
                                  cmd, optarg);
                return LVM_EINVALID_CMD_LINE;
             }
@@ -211,7 +206,7 @@ int main ( int argc, char **argv) {
             if ( ( stripesize = lvm_check_number ( optarg, FALSE)) > 0) {
                opt_I++;
             } else {
-               fprintf ( stderr, "%s -- ERROR option I argument \"%s\"\n",
+               fprintf ( stderr, "%s -- ERROR option I argument \"%s\"\n\n",
                                  cmd, optarg);
                return LVM_EINVALID_CMD_LINE;
             }
