@@ -18,7 +18,7 @@
  * GNU General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with GNU CC; see the file COPYING.  If not, write to
+ * along with LVM; see the file COPYING.  If not, write to
  * the Free Software Foundation, 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA. 
  *
@@ -439,22 +439,24 @@ int main ( int argc, char **argv) {
                return LVM_EVGCHANGE_VG_WRITE;
             }
       
-            if ( opt_v > 0) printf ( "%s -- changing VGDA in kernel\n", cmd);
-            if ( set_extendable == TRUE) {
-               ret = vg_set_extendable ( vg_name);
-            } else {
-               ret = vg_clear_extendable ( vg_name);
-            }
-            if ( ret < 0) {
-               fprintf ( stderr, "%s -- ERROR %d ", cmd, ret);
+            if ( vg_check_active ( vg_name) == TRUE) {
+               if ( opt_v > 0) printf ( "%s -- changing VGDA in kernel\n", cmd);
                if ( set_extendable == TRUE) {
-                   fprintf ( stderr, "en");
+                  ret = vg_set_extendable ( vg_name);
                } else {
-                   fprintf ( stderr, "dis");
-              }
-              fprintf ( stderr, "abling extension of volume group \"%s\"\n\n",
-                                vg_name);
-              return LVM_EVGCHANGE_VG_EXTEND;
+                  ret = vg_clear_extendable ( vg_name);
+               }
+               if ( ret < 0) {
+                  fprintf ( stderr, "%s -- ERROR %d ", cmd, ret);
+                  if ( set_extendable == TRUE) {
+                      fprintf ( stderr, "en");
+                  } else {
+                      fprintf ( stderr, "dis");
+                 }
+                 fprintf ( stderr, "abling extension of volume group \"%s\"\n\n",
+                                   vg_name);
+                 return LVM_EVGCHANGE_VG_EXTEND;
+               }
             }
 
             if ( opt_v > 0) printf ( "%s -- changing lvmtab\n", cmd);
@@ -487,6 +489,14 @@ int main ( int argc, char **argv) {
                               cmd, vg_name);
             continue;
          }
+
+         if ( ! ( vg->vg_status & VG_EXTENDABLE)) {
+            fprintf ( stderr, "%s -- volume group \"%s\"must be extendable "
+                              "to change MaxLogicalVolume\n",
+                              cmd, vg_name);
+            continue;
+         }
+
          if ( opt_v > 0) printf ( "%s -- checking if MaxLogicalVolume fits\n",
                                   cmd);
          if ( max_lv <= vg->lv_cur) {
